/*
  Copyright (C) 2003  Taiga Yonekura, taiga@col.hi-ho.ne.jp

  For more information about this appliation please look at:
   http://www.pat.hi-ho.ne.jp/kyonekura

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/
#ifndef ENEMY_H
#define ENEMY_H

#include <qpixmap.h>

#define CENEMY_IMGCNT 3

class CEnemy
{

 public:
  CEnemy(int strong);
  int getStrong();
  void setImages(QPixmap *img[]);
  QPixmap *getLostImage();
  QPixmap *getWinImage();
  QPixmap *getNormalImage();
  QPixmap *getImage();
  void setResult(unsigned int win, unsigned int lost );
  void getResult(unsigned int* win, unsigned int* lost );
  void win();
  void lost();

 private:
  int m_strong;     /*  ɤ߿          */
  QPixmap *m_Img[CENEMY_IMGCNT];
  unsigned int m_result[2]; //0:win 1:lost
  
};

#endif



